@@ -49,7 +49,7 @@ class EnvironmentsGrpcAsyncIOTransport(EnvironmentsTransport):
     def create_channel(
         cls,
         host: str = "composer.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -92,15 +92,15 @@ class EnvironmentsGrpcAsyncIOTransport(EnvironmentsTransport):
         self,
         *,
         host: str = "composer.googleapis.com",
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        channel: aio.Channel = None,
-        api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
-        ssl_channel_credentials: grpc.ChannelCredentials = None,
-        client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
-        quota_project_id=None,
+        channel: Optional[aio.Channel] = None,
+        api_mtls_endpoint: Optional[str] = None,
+        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
+        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         always_use_jwt_access: Optional[bool] = False,
         api_audience: Optional[str] = None,
@@ -390,8 +390,123 @@ class EnvironmentsGrpcAsyncIOTransport(EnvironmentsTransport):
             )
         return self._stubs["delete_environment"]
 
+    @property
+    def save_snapshot(
+        self,
+    ) -> Callable[
+        [environments.SaveSnapshotRequest], Awaitable[operations_pb2.Operation]
+    ]:
+        r"""Return a callable for the save snapshot method over gRPC.
+
+        Creates a snapshots of a Cloud Composer environment.
+        As a result of this operation, snapshot of environment's
+        state is stored in a location specified in the
+        SaveSnapshotRequest.
+
+        Returns:
+            Callable[[~.SaveSnapshotRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "save_snapshot" not in self._stubs:
+            self._stubs["save_snapshot"] = self.grpc_channel.unary_unary(
+                "/google.cloud.orchestration.airflow.service.v1.Environments/SaveSnapshot",
+                request_serializer=environments.SaveSnapshotRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["save_snapshot"]
+
+    @property
+    def load_snapshot(
+        self,
+    ) -> Callable[
+        [environments.LoadSnapshotRequest], Awaitable[operations_pb2.Operation]
+    ]:
+        r"""Return a callable for the load snapshot method over gRPC.
+
+        Loads a snapshot of a Cloud Composer environment.
+        As a result of this operation, a snapshot of
+        environment's specified in LoadSnapshotRequest is loaded
+        into the environment.
+
+        Returns:
+            Callable[[~.LoadSnapshotRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "load_snapshot" not in self._stubs:
+            self._stubs["load_snapshot"] = self.grpc_channel.unary_unary(
+                "/google.cloud.orchestration.airflow.service.v1.Environments/LoadSnapshot",
+                request_serializer=environments.LoadSnapshotRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["load_snapshot"]
+
     def close(self):
         return self.grpc_channel.close()
 
+    @property
+    def delete_operation(
+        self,
+    ) -> Callable[[operations_pb2.DeleteOperationRequest], None]:
+        r"""Return a callable for the delete_operation method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_operation" not in self._stubs:
+            self._stubs["delete_operation"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/DeleteOperation",
+                request_serializer=operations_pb2.DeleteOperationRequest.SerializeToString,
+                response_deserializer=None,
+            )
+        return self._stubs["delete_operation"]
+
+    @property
+    def get_operation(
+        self,
+    ) -> Callable[[operations_pb2.GetOperationRequest], operations_pb2.Operation]:
+        r"""Return a callable for the get_operation method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_operation" not in self._stubs:
+            self._stubs["get_operation"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/GetOperation",
+                request_serializer=operations_pb2.GetOperationRequest.SerializeToString,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["get_operation"]
+
+    @property
+    def list_operations(
+        self,
+    ) -> Callable[
+        [operations_pb2.ListOperationsRequest], operations_pb2.ListOperationsResponse
+    ]:
+        r"""Return a callable for the list_operations method over gRPC."""
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_operations" not in self._stubs:
+            self._stubs["list_operations"] = self.grpc_channel.unary_unary(
+                "/google.longrunning.Operations/ListOperations",
+                request_serializer=operations_pb2.ListOperationsRequest.SerializeToString,
+                response_deserializer=operations_pb2.ListOperationsResponse.FromString,
+            )
+        return self._stubs["list_operations"]
+
 
 __all__ = ("EnvironmentsGrpcAsyncIOTransport",)
