@@ -25,13 +25,23 @@ from .environments import (
     IPAllocationPolicy,
     ListEnvironmentsRequest,
     ListEnvironmentsResponse,
+    LoadSnapshotRequest,
+    LoadSnapshotResponse,
+    MaintenanceWindow,
+    MasterAuthorizedNetworksConfig,
+    NetworkingConfig,
     NodeConfig,
     PrivateClusterConfig,
     PrivateEnvironmentConfig,
+    RecoveryConfig,
+    SaveSnapshotRequest,
+    SaveSnapshotResponse,
+    ScheduledSnapshotsConfig,
     SoftwareConfig,
     UpdateEnvironmentRequest,
     WebServerConfig,
     WebServerNetworkAccessControl,
+    WorkloadsConfig,
 )
 from .image_versions import (
     ImageVersion,
@@ -52,13 +62,23 @@ __all__ = (
     "IPAllocationPolicy",
     "ListEnvironmentsRequest",
     "ListEnvironmentsResponse",
+    "LoadSnapshotRequest",
+    "LoadSnapshotResponse",
+    "MaintenanceWindow",
+    "MasterAuthorizedNetworksConfig",
+    "NetworkingConfig",
     "NodeConfig",
     "PrivateClusterConfig",
     "PrivateEnvironmentConfig",
+    "RecoveryConfig",
+    "SaveSnapshotRequest",
+    "SaveSnapshotResponse",
+    "ScheduledSnapshotsConfig",
     "SoftwareConfig",
     "UpdateEnvironmentRequest",
     "WebServerConfig",
     "WebServerNetworkAccessControl",
+    "WorkloadsConfig",
     "ImageVersion",
     "ListImageVersionsRequest",
     "ListImageVersionsResponse",
