@@ -13,14 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
+from __future__ import annotations
+
+from typing import MutableMapping, MutableSequence
 
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.orchestration.airflow.service.v1",
-    manifest={"OperationMetadata",},
+    manifest={
+        "OperationMetadata",
+    },
 )
 
 
@@ -51,7 +55,24 @@ class OperationMetadata(proto.Message):
     """
 
     class State(proto.Enum):
-        r"""An enum describing the overall state of an operation."""
+        r"""An enum describing the overall state of an operation.
+
+        Values:
+            STATE_UNSPECIFIED (0):
+                Unused.
+            PENDING (1):
+                The operation has been created but is not yet
+                started.
+            RUNNING (2):
+                The operation is underway.
+            SUCCEEDED (3):
+                The operation completed successfully.
+            SUCCESSFUL (3):
+                No description available.
+            FAILED (4):
+                The operation is no longer running but did
+                not succeed.
+        """
         _pb_options = {"allow_alias": True}
         STATE_UNSPECIFIED = 0
         PENDING = 1
@@ -61,19 +82,60 @@ class OperationMetadata(proto.Message):
         FAILED = 4
 
     class Type(proto.Enum):
-        r"""Type of longrunning operation."""
+        r"""Type of longrunning operation.
+
+        Values:
+            TYPE_UNSPECIFIED (0):
+                Unused.
+            CREATE (1):
+                A resource creation operation.
+            DELETE (2):
+                A resource deletion operation.
+            UPDATE (3):
+                A resource update operation.
+            CHECK (4):
+                A resource check operation.
+            SAVE_SNAPSHOT (5):
+                Saves snapshot of the resource operation.
+            LOAD_SNAPSHOT (6):
+                Loads snapshot of the resource operation.
+        """
         TYPE_UNSPECIFIED = 0
         CREATE = 1
         DELETE = 2
         UPDATE = 3
         CHECK = 4
+        SAVE_SNAPSHOT = 5
+        LOAD_SNAPSHOT = 6
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    operation_type = proto.Field(proto.ENUM, number=2, enum=Type,)
-    resource = proto.Field(proto.STRING, number=3,)
-    resource_uuid = proto.Field(proto.STRING, number=4,)
-    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
+    state: State = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    operation_type: Type = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=Type,
+    )
+    resource: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    resource_uuid: str = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    create_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time: timestamp_pb2.Timestamp = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
