@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,10 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.orchestration.airflow.service_v1beta1 import (
+    gapic_version as package_version,
+)
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,6 +46,7 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -130,7 +144,7 @@ class EnvironmentsAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -166,9 +180,9 @@ class EnvironmentsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, EnvironmentsTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the environments client.
@@ -212,12 +226,12 @@ class EnvironmentsAsyncClient:
 
     async def create_environment(
         self,
-        request: Union[environments.CreateEnvironmentRequest, dict] = None,
+        request: Optional[Union[environments.CreateEnvironmentRequest, dict]] = None,
         *,
-        parent: str = None,
-        environment: environments.Environment = None,
+        parent: Optional[str] = None,
+        environment: Optional[environments.Environment] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Create a new environment.
@@ -246,13 +260,13 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.CreateEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.CreateEnvironmentRequest, dict]]):
                 The request object. Create a new environment.
             parent (:class:`str`):
                 The parent must be of the form
@@ -335,11 +349,11 @@ class EnvironmentsAsyncClient:
 
     async def get_environment(
         self,
-        request: Union[environments.GetEnvironmentRequest, dict] = None,
+        request: Optional[Union[environments.GetEnvironmentRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> environments.Environment:
         r"""Get an existing environment.
@@ -370,7 +384,7 @@ class EnvironmentsAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.GetEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.GetEnvironmentRequest, dict]]):
                 The request object. Get an environment.
             name (:class:`str`):
                 The resource name of the environment
@@ -436,11 +450,11 @@ class EnvironmentsAsyncClient:
 
     async def list_environments(
         self,
-        request: Union[environments.ListEnvironmentsRequest, dict] = None,
+        request: Optional[Union[environments.ListEnvironmentsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListEnvironmentsAsyncPager:
         r"""List environments.
@@ -472,7 +486,7 @@ class EnvironmentsAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.ListEnvironmentsRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.ListEnvironmentsRequest, dict]]):
                 The request object. List environments in a project and
                 location.
             parent (:class:`str`):
@@ -551,13 +565,13 @@ class EnvironmentsAsyncClient:
 
     async def update_environment(
         self,
-        request: Union[environments.UpdateEnvironmentRequest, dict] = None,
+        request: Optional[Union[environments.UpdateEnvironmentRequest, dict]] = None,
         *,
-        name: str = None,
-        environment: environments.Environment = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        name: Optional[str] = None,
+        environment: Optional[environments.Environment] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Update an environment.
@@ -586,13 +600,13 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.UpdateEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.UpdateEnvironmentRequest, dict]]):
                 The request object. Update an environment.
             name (:class:`str`):
                 The relative resource name of the
@@ -726,7 +740,11 @@ class EnvironmentsAsyncClient:
                    -  Horizontally scale the number of nodes in the
                       environment. An integer greater than or equal to 3
                       must be provided in the ``config.nodeCount``
-                      field. \* ``config.webServerNetworkAccessControl``
+                      field. Supported for Cloud Composer environments
+                      in versions composer-1.\ *.*-airflow-*.*.*.
+
+                -  ``config.webServerNetworkAccessControl``
+
                    -  Replace the environment's current
                       WebServerNetworkAccessControl.
 
@@ -757,9 +775,7 @@ class EnvironmentsAsyncClient:
                    -  Replace all environment variables. If a
                       replacement environment variable map is not
                       included in ``environment``, all custom
-                      environment variables are cleared. It is an error
-                      to provide both this mask and a mask specifying
-                      one or more individual environment variables.
+                      environment variables are cleared.
 
                 -  ``config.softwareConfig.imageVersion``
 
@@ -767,11 +783,11 @@ class EnvironmentsAsyncClient:
                       Refer to ``SoftwareConfig.image_version`` for
                       information on how to format the new image
                       version. Additionally, the new image version
-                      cannot effect a version downgrade and must match
-                      the current image version's Composer major version
-                      and Airflow major and minor versions. Consult the
-                      `Cloud Composer Version
-                      List <https://cloud.google.com/composer/docs/concepts/versioning/composer-versions>`__
+                      cannot effect a version downgrade, and must match
+                      the current image version's Composer and Airflow
+                      major versions. Consult the `Cloud Composer
+                      version
+                      list </composer/docs/concepts/versioning/composer-versions>`__
                       for valid values.
 
                 -  ``config.softwareConfig.schedulerCount``
@@ -779,21 +795,52 @@ class EnvironmentsAsyncClient:
                    -  Horizontally scale the number of schedulers in
                       Airflow. A positive integer not greater than the
                       number of nodes must be provided in the
-                      ``config.softwareConfig.schedulerCount`` field. \*
-                      ``config.databaseConfig.machineType``
+                      ``config.softwareConfig.schedulerCount`` field.
+                      Supported for Cloud Composer environments in
+                      versions composer-1.\ *.*-airflow-2.*.*.
+
+                -  ``config.softwareConfig.cloudDataLineageIntegration``
+
+                   -  Configuration for Cloud Data Lineage integration.
+
+                -  ``config.databaseConfig.machineType``
+
                    -  Cloud SQL machine type used by Airflow database.
                       It has to be one of: db-n1-standard-2,
                       db-n1-standard-4, db-n1-standard-8 or
-                      db-n1-standard-16. \*
-                      ``config.webServerConfig.machineType``
+                      db-n1-standard-16. Supported for Cloud Composer
+                      environments in versions
+                      composer-1.\ *.*-airflow-*.*.*.
+
+                -  ``config.webServerConfig.machineType``
+
                    -  Machine type on which Airflow web server is
                       running. It has to be one of:
                       composer-n1-webserver-2, composer-n1-webserver-4
-                      or composer-n1-webserver-8. \*
-                      ``config.maintenanceWindow``
+                      or composer-n1-webserver-8. Supported for Cloud
+                      Composer environments in versions
+                      composer-1.\ *.*-airflow-*.*.*.
+
+                -  ``config.maintenanceWindow``
+
                    -  Maintenance window during which Cloud Composer
                       components may be under maintenance.
 
+                -  ``config.workloadsConfig``
+
+                   -  The workloads configuration settings for the GKE
+                      cluster associated with the Cloud Composer
+                      environment. Supported for Cloud Composer
+                      environments in versions
+                      composer-2.\ *.*-airflow-*.*.\* and newer.
+
+                -  ``config.environmentSize``
+
+                   -  The size of the Cloud Composer environment.
+                      Supported for Cloud Composer environments in
+                      versions composer-2.\ *.*-airflow-*.*.\* and
+                      newer.
+
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -868,11 +915,11 @@ class EnvironmentsAsyncClient:
 
     async def delete_environment(
         self,
-        request: Union[environments.DeleteEnvironmentRequest, dict] = None,
+        request: Optional[Union[environments.DeleteEnvironmentRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Delete an environment.
@@ -901,13 +948,13 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.DeleteEnvironmentRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.DeleteEnvironmentRequest, dict]]):
                 The request object. Delete an environment.
             name (:class:`str`):
                 The environment to delete, in the
@@ -991,10 +1038,10 @@ class EnvironmentsAsyncClient:
 
     async def restart_web_server(
         self,
-        request: Union[environments.RestartWebServerRequest, dict] = None,
+        request: Optional[Union[environments.RestartWebServerRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Restart Airflow web server.
@@ -1023,13 +1070,13 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.RestartWebServerRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.RestartWebServerRequest, dict]]):
                 The request object. Restart Airflow web server.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -1084,10 +1131,10 @@ class EnvironmentsAsyncClient:
 
     async def check_upgrade(
         self,
-        request: Union[environments.CheckUpgradeRequest, dict] = None,
+        request: Optional[Union[environments.CheckUpgradeRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Check if an upgrade operation on the environment will
@@ -1119,13 +1166,13 @@ class EnvironmentsAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.orchestration.airflow.service_v1beta1.types.CheckUpgradeRequest, dict]):
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.CheckUpgradeRequest, dict]]):
                 The request object. Request to check whether image
                 upgrade will succeed.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1180,6 +1227,367 @@ class EnvironmentsAsyncClient:
         # Done; return the response.
         return response
 
+    async def save_snapshot(
+        self,
+        request: Optional[Union[environments.SaveSnapshotRequest, dict]] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Creates a snapshots of a Cloud Composer environment.
+        As a result of this operation, snapshot of environment's
+        state is stored in a location specified in the
+        SaveSnapshotRequest.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.orchestration.airflow import service_v1beta1
+
+            async def sample_save_snapshot():
+                # Create a client
+                client = service_v1beta1.EnvironmentsAsyncClient()
+
+                # Initialize request argument(s)
+                request = service_v1beta1.SaveSnapshotRequest(
+                )
+
+                # Make the request
+                operation = client.save_snapshot(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = (await operation).result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.SaveSnapshotRequest, dict]]):
+                The request object. Request to create a snapshot of a
+                Cloud Composer environment.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.orchestration.airflow.service_v1beta1.types.SaveSnapshotResponse`
+                Response to SaveSnapshotRequest.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = environments.SaveSnapshotRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.save_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("environment", request.environment),)
+            ),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            environments.SaveSnapshotResponse,
+            metadata_type=operations.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def load_snapshot(
+        self,
+        request: Optional[Union[environments.LoadSnapshotRequest, dict]] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operation_async.AsyncOperation:
+        r"""Loads a snapshot of a Cloud Composer environment.
+        As a result of this operation, a snapshot of
+        environment's specified in LoadSnapshotRequest is loaded
+        into the environment.
+
+        .. code-block:: python
+
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
+            from google.cloud.orchestration.airflow import service_v1beta1
+
+            async def sample_load_snapshot():
+                # Create a client
+                client = service_v1beta1.EnvironmentsAsyncClient()
+
+                # Initialize request argument(s)
+                request = service_v1beta1.LoadSnapshotRequest(
+                )
+
+                # Make the request
+                operation = client.load_snapshot(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = (await operation).result()
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Optional[Union[google.cloud.orchestration.airflow.service_v1beta1.types.LoadSnapshotRequest, dict]]):
+                The request object. Request to load a snapshot into a
+                Cloud Composer environment.
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            google.api_core.operation_async.AsyncOperation:
+                An object representing a long-running operation.
+
+                The result type for the operation will be
+                :class:`google.cloud.orchestration.airflow.service_v1beta1.types.LoadSnapshotResponse`
+                Response to LoadSnapshotRequest.
+
+        """
+        # Create or coerce a protobuf request object.
+        request = environments.LoadSnapshotRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method_async.wrap_method(
+            self._client._transport.load_snapshot,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("environment", request.environment),)
+            ),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Wrap the response in an operation future.
+        response = operation_async.from_gapic(
+            response,
+            self._client._transport.operations_client,
+            environments.LoadSnapshotResponse,
+            metadata_type=operations.OperationMetadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def list_operations(
+        self,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.ListOperationsResponse:
+        r"""Lists operations that match the specified filter in the request.
+
+        Args:
+            request (:class:`~.operations_pb2.ListOperationsRequest`):
+                The request object. Request message for
+                `ListOperations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.ListOperationsResponse:
+                Response message for ``ListOperations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.ListOperationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.list_operations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def get_operation(
+        self,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.Operation:
+        r"""Gets the latest state of a long-running operation.
+
+        Args:
+            request (:class:`~.operations_pb2.GetOperationRequest`):
+                The request object. Request message for
+                `GetOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.Operation:
+                An ``Operation`` object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.GetOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.get_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def delete_operation(
+        self,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> None:
+        r"""Deletes a long-running operation.
+
+        This method indicates that the client is no longer interested
+        in the operation result. It does not cancel the operation.
+        If the server doesn't support this method, it returns
+        `google.rpc.Code.UNIMPLEMENTED`.
+
+        Args:
+            request (:class:`~.operations_pb2.DeleteOperationRequest`):
+                The request object. Request message for
+                `DeleteOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            None
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.DeleteOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.delete_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
     async def __aenter__(self):
         return self
 
@@ -1187,14 +1595,9 @@ class EnvironmentsAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-orchestration-airflow-service",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("EnvironmentsAsyncClient",)
