@@ -16,21 +16,32 @@
 from .environments import (
     CheckUpgradeRequest,
     CheckUpgradeResponse,
+    CloudDataLineageIntegration,
     CreateEnvironmentRequest,
     DatabaseConfig,
     DeleteEnvironmentRequest,
     EncryptionConfig,
     Environment,
     EnvironmentConfig,
+    ExecuteAirflowCommandResponse,
     GetEnvironmentRequest,
     IPAllocationPolicy,
     ListEnvironmentsRequest,
     ListEnvironmentsResponse,
+    LoadSnapshotRequest,
+    LoadSnapshotResponse,
     MaintenanceWindow,
+    MasterAuthorizedNetworksConfig,
+    NetworkingConfig,
     NodeConfig,
+    PollAirflowCommandResponse,
     PrivateClusterConfig,
     PrivateEnvironmentConfig,
+    RecoveryConfig,
     RestartWebServerRequest,
+    SaveSnapshotRequest,
+    SaveSnapshotResponse,
+    ScheduledSnapshotsConfig,
     SoftwareConfig,
     UpdateEnvironmentRequest,
     WebServerConfig,
@@ -47,21 +58,32 @@ from .operations import OperationMetadata
 __all__ = (
     "CheckUpgradeRequest",
     "CheckUpgradeResponse",
+    "CloudDataLineageIntegration",
     "CreateEnvironmentRequest",
     "DatabaseConfig",
     "DeleteEnvironmentRequest",
     "EncryptionConfig",
     "Environment",
     "EnvironmentConfig",
+    "ExecuteAirflowCommandResponse",
     "GetEnvironmentRequest",
     "IPAllocationPolicy",
     "ListEnvironmentsRequest",
     "ListEnvironmentsResponse",
+    "LoadSnapshotRequest",
+    "LoadSnapshotResponse",
     "MaintenanceWindow",
+    "MasterAuthorizedNetworksConfig",
+    "NetworkingConfig",
     "NodeConfig",
+    "PollAirflowCommandResponse",
     "PrivateClusterConfig",
     "PrivateEnvironmentConfig",
+    "RecoveryConfig",
     "RestartWebServerRequest",
+    "SaveSnapshotRequest",
+    "SaveSnapshotResponse",
+    "ScheduledSnapshotsConfig",
     "SoftwareConfig",
     "UpdateEnvironmentRequest",
     "WebServerConfig",
